@@ -6,7 +6,7 @@ import inspect
 # endregion
 
 
-class LoggerFormatter:
+class Logger:
     """Provide functions for managing log messages."""
 
     def __init__(self, unique_id: str = "", prefix: str = ""):
@@ -14,7 +14,7 @@ class LoggerFormatter:
         self._unique_id: str = unique_id
         self._prefix: str = prefix
 
-    def message_format(self, msg: str, include_lineno: bool = False) -> str:
+    def format(self, msg: str, include_lineno: bool = False) -> str:
         """Format a log message in the correct format."""
         caller: inspect.FrameInfo = inspect.stack()[1]
         line_no = f" --> line: {caller.lineno}" if include_lineno else ""
